/* vi:set ts=8 sts=4 sw=4:
 * vi:set comments=sbl\:*\ -,mb\:*,el\:*\ -,sr\:/\*,mb\:*,el\:*\/,fb\:- :
 *
 * VIM - Vi IMproved		by Bram Moolenaar
 *
 * Do ":help uganda"  in Vim to read copying and usage conditions.
 * Do ":help credits" in Vim to see a list of people who contributed.
 */

#include "vim.h"

/*
 * Vim originated from Stevie version 3.6 (Fish disk 217) by GRWalter (Fred)
 * It has been changed beyond recognition since then.
 *
 * Differences between version 4.x and 5.0 can be found with ":help version5".
 * Differences between version 3.0 and 4.x can be found with ":help version4".
 * All the remarks about older versions have been removed, they are not very
 * interesting.
 *
 * Changes between version 5.0s and 5.0t:
 * - Fixed for OS/2: Unused var in os_unix.c.  Making ctags didn't work.
 * - Added 'mousehide' functionality for Win32 GUI (Moore).
 * - Fixed in X11 GUI: When an operator is pending, a mouse movement was
 *   recognized (Ralston).  Also fixes blinking problem.
 * - Fixed: CTRL-W ] didn't use count to set window height.
 * - Fixed: "-font" command line argument didn't override 'guifont' setting
 *   from .gvimrc. (Acevedo)
 * - Fixed: clipboard wasn't used for "*y".  And some more Win32/X11
 *   differences fixed for the clipboard (Webb).
 * - Fixed: jumping from one help file to another help file, with 'compatible'
 *   set, removed the 'help' flag from the buffer.
 * - Fixed: In a "normal" terminal, the "~" lines at the end would be followed
 *   by a row of spaces, instead of using the clear-to-end-of-line.  Now a
 *   space that is bold or italic is assumed to be the same as a space.
 * - Fixed: "vim -q" caused a crash.
 * - Fixed: When the bold attribute is set for cterm to get light colors, it
 *   wasn't reset when using another (not light) color.
 * - Fixed: When using a xterm-color with 16 colors, colors where wrong, and
 *   it didn't work for termcap systems.  Now Vim guesses the type of
 *   terminal, and adjusts the termcap entry itself.  This is Magic!
 * - Added: A few builtin colors for X11, in case the rgb.txt file doesn't
 *   have these (only the ones that have been reported to be missing).
 * - Added missing files for BeOS GUI.
 * - Fixed: Win32 clipboard didn't work for copy-paste within the same Vim
 *   session (it did work in other applications). (Webb)
 * - Fixed: When changing 'fileformat', so that the file is marked 'changed',
 *   and then writing it, doesn't redraw the status line to show the file
 *   isn't changed anymore.
 * - Fixed: File-writable bit could be reset when using ":w!" for a readonly
 *   file.
 * - Fixed: Count for ":ball" was ignored.  Some of the file-read messages for
 *   ":10ball" were cleared.  ":5ball" could result in more than 5 windows.
 * - Fixed: ":list" showed " $ist" on an empty line.
 * - Added: ":buffer" now supports a "!": abandon changes in current buffer.
 *   Also ":bnext", ":brewind", etc.  Needed now that 'hidden' is used.
 * - Fixed: There was a wait for CTRL-O n in Insert mode, because the search
 *   pattern was shown.
 * - Reduced wait, to allow reading a message, from 10 to 3 seconds.  It
 *   seemed nothing was happening.
 * - Fixed: When using a matchgroup in a region, ":syn" showed
 *   "matchgroup=NONE" for a following match item.
 * - Added: ":highlight clear {group}", as an alternative to ":highlight
 *   {group} NONE".  More consistant with ":syntax clear {group}".
 * - Fixed: In gvim, in Ex mode, special keys like <BS> and <DEL> didn't work.
 * - Fixed: ":recover" found same swap file twice.
 * - Fixed: "*yy only worked the second time (when pasting to an xterm)."
 * - Fixed: in DJGPP version (dos32), the system flags were cleared.
 * - Added: Leading context setting for region item: "lc=99" (Bigham).
 * - Fixed: Python version 1.5 didn't work (1.4 did work). (Leonard)
 * - Added: hostname() function in expressions. (Moore)
 * - Fixed: ":syntax off" only switched off highlighting for the current
 *   window.  Now it does that for all buffers.
 * - Fixed: "/^." with 'hlsearch' set highlighted too much.
 * - Fixed: in dos32 version, underscores were sometimes replaced with
 *   y-umlaut (Levin).
 * - Fixed: version 4.1 of ncurses can't handle tputs("", ..).  Avoid calling
 *   tputs() with an empty string.
 * - Added: ":tnext", ":tlast", etc. commands: jump to other matching tags.
 *   Useful when more than one tag matches.  Also added: include matches with
 *   ignoring case when expanding tag names.
 * - Fixed: ":hi clear" and ":hi link" gave confusing error message.
 * - Fixed: ":set term=xxx" produced garbage output.
 * - Fixed: When finding a matching tag, but the file doesn't exist, continue
 *   searching for another match.  Helps when using the same tags file (with
 *   links) for different versions of source code.
 * - Fixed: in Win32 GUI, killing an extenal command with CTRL-C sometimes
 *   killed Vim (Aaron).
 * - Fixed: <S-Tab> in the command line worked like CTRL-P when no completion
 *   started yet.  Now it does completion, last match first.
 *
 * Changes between version 5.0r and 5.0s:
 * - Fixed: Restored some functional comments that were accidently removed
 *   from osdef2.h.in.
 * - Added "\S" to regexp patterns: matches a non-white character.  Changed
 *   "\w" to "\s", to make it similar with Perl.
 * - Fixed: Sniff interface could hang in GUI.  (Leherbauer)
 * - Fixed: An expression with [] indexing didn't always work, because it was
 *   accessing already freed memory.  (Acevedo) Also added a check for
 *   a negative index.
 * - Fixed: When switching windows in ":normal" command, some windows may not
 *   be redrawn correctly.
 * - Fixed: When starting gvim from a menu, the window size would be very
 *   small.
 * - Fixed: MSDOS: mouse positioning was off by 50%.
 * - Fixed: Insert mode completion with ^X^L didn't always work correctly
 *   (Acevedo).
 * - Added: Keyword highlighting can now be specified like "ab[breviation]",
 *   which means there is a required part and an optional part (per letter).
 * - Added: Installation of bugreport.vim in Makefile.
 * - Added: 'mousehide' option, to hide mouse pointer in GUI when typing
 *   text.  (Ralston)
 * - Fixed: Pasting with the mouse in Replace mode, a redo would use the
 *   pasted text twice.
 * - Moved check for "linux" terminal to before reading the .vimrc, so that
 *   'background' is set before using "syntax on".
 * - Fixed: Some problems with executing external/filter commands.  Don't put
 *   a space after '>' or '<' for redirection.  Added 'shellxquote' option:
 *   add extra quotes around the whole shell command, including redirection.
 * - Changed: substitute() has an extra "flags" argument.  Will support 'g'
 *   in the future (not implemented yet).
 * - Fixed: was not possible to have a region contain regions that match the
 *   same end pattern, while still ending the region.  Added "keepend"
 *   argument for this.
 * - Updated feature.h.  Allow a choice for minimal or maximal features in an
 *   easy way.  Use minimal features for the DOS16 version.
 * - Added: Highlight '$' at the end of the line when 'list' is set as
 *   "NonText".
 * - Fixed: When 'cpo' contains 'S', jumping to another window from a help
 *   window and back, removed the help flag for that window.
 * - Fixed: When splitting a window, making a change, and the ":e!" only
 *   redrawed the current window (sometimes).
 * - Fixed: When using BufEnter autocommand that adds a line, splitting the
 *   window and doing ":e!" caused an "invalid lnum" error.  Added check for
 *   valid cursor.lnum and topline before executing autocommands.
 * - Fixed: Doing '%' on a line that starts with "   #if" didn't jump to
 *   matching "#else".  Don't recognize these for '%' when 'cpo' contains the
 *   '%' flag.
 * - Added fixes for 'complet' option (Acevedo).
 * - Fixed: Crash when a tags file line didn't contain enough TABs, and
 *   TAG_ANY_WHITE is not defined.
 * - Fixed: When "nextgroup" used in a syntax item, this didn't work for the
 *   very last character in the iine.
 * - Added VisVim in the extra archive.
 * - Fixed: "aB" didn't set mark.
 * - Fixed: for DJGPP use the shell when redirecting (otherwise DJGPP's
 *   system() will do it, which is not always what we want).
 * - Fixed: When doing ":e" to edit hidden buffer, 'fileformat' was reset to
 *   default format (first one in 'fileformats').
 * - Fixed: wildcards in 'path' didn't work for non-Unix systems, when the
 *   path starts with something like "e:".
 * - Fixed: For DOS the viminfo file was always written in "c:/".  Now it's
 *   only in "C:/" when both $HOME and $VIM are not defined.
 * - Fixed: ":syn sync clear" didn't work.
 * - Added: In Win32 GUI, setting 'guifont' to "*" brings up a font requester.
 * - Fixed: ":only" removed status line if other window could not be closed,
 *   because of changes.
 * - Fixed: ":so! file" didn't work correctly when used in a mapping.  The
 *   following commands in the mapping were executed before reading from the
 *   script.
 */

#include "version.h"

char	*Version = VIM_VERSION_SHORT;
char	*mediumVersion = VIM_VERSION_MEDIUM;
#ifdef HAVE_DATE_TIME
char	*longVersion = VIM_VERSION_LONG_DATE __DATE__ " " __TIME__ ")";
#else
char	*longVersion = VIM_VERSION_LONG;
#endif

static void version_msg __ARGS((char *s));

    int
get_version()
{
    return (VIM_VERSION_MAJOR * 100 + VIM_VERSION_MINOR);
}

    void
do_version(arg)
    char_u  *arg;
{
    /*
     * Ignore a ":version 9.99" command.
     */
    if (*arg == NUL)
    {
	/*
	 * When adding features here, don't forget to update the list of
	 * internal variables in eval.c!
	 */
	msg_putchar('\n');
	MSG(longVersion);
#ifdef WIN32
	MSG_PUTS("\nWindows NT / Windows 95 version");
#endif
#ifdef MSDOS
# ifdef DJGPP
	MSG_PUTS("\n32 bit MS-DOS version");
# else
	MSG_PUTS("\n16 bit MS-DOS version");
# endif
#endif
	MSG_PUTS("\nCompiled with (+) or without (-):\n");
#ifdef AMIGA		/* only for Amiga systems */
# ifdef NO_ARP
	version_msg("-ARP ");
# else
	version_msg("+ARP ");
# endif
#endif
#ifdef AUTOCMD
	version_msg("+autocmd ");
#else
	version_msg("-autocmd ");
#endif
#ifdef NO_BUILTIN_TCAPS
	version_msg("-builtin_terms ");
#endif
#ifdef SOME_BUILTIN_TCAPS
	version_msg("+builtin_terms ");
#endif
#ifdef ALL_BUILTIN_TCAPS
	version_msg("++builtin_terms ");
#endif
#ifdef CINDENT
	version_msg("+cindent ");
#else
	version_msg("-cindent ");
#endif
#ifdef DIGRAPHS
	version_msg("+digraphs ");
#else
	version_msg("-digraphs ");
#endif
#ifdef EMACS_TAGS
	version_msg("+emacs_tags ");
#else
	version_msg("-emacs_tags ");
#endif
#ifdef FKMAP
	version_msg("+farsi ");
#else
	version_msg("-farsi ");
#endif
	    /* only interesting on Unix systems */
#if !defined(USE_SYSTEM) && defined(UNIX)
	version_msg("+fork() ");
#endif
#ifdef UNIX
# ifdef USE_GUI_MOTIF
	version_msg("+GUI_Motif ");
# else
#  ifdef USE_GUI_ATHENA
	version_msg("+GUI_Athena ");
#  else
#   ifdef USE_GUI_BEOS
	version_msg("+GUI_BeOS ");
#    else
	version_msg("-GUI ");
#   endif
#  endif
# endif
#endif
#ifdef INSERT_EXPAND
	version_msg("+insert_expand ");
#else
	version_msg("-insert_expand ");
#endif
#ifdef HAVE_LANGMAP
	version_msg("+langmap ");
#else
	version_msg("-langmap ");
#endif
#ifdef LISPINDENT
	version_msg("+lispindent ");
#else
	version_msg("-lispindent ");
#endif
#ifdef HAVE_OLE
	version_msg("+ole ");
#else
	version_msg("-ole ");
#endif
#ifdef HAVE_PERL_INTERP
	version_msg("+perl ");
#else
	version_msg("-perl ");
#endif
#ifdef HAVE_PYTHON
	version_msg("+python ");
#else
	version_msg("-python ");
#endif
#ifdef RIGHTLEFT
	version_msg("+rightleft ");
#else
	version_msg("-rightleft ");
#endif
#ifdef SMARTINDENT
	version_msg("+smartindent ");
#else
	version_msg("-smartindent ");
#endif
	    /* only interesting on Unix systems */
#if defined(USE_SYSTEM) && (defined(UNIX) || defined(__EMX__))
	version_msg("+system() ");
#endif
#if defined(UNIX) || defined(__EMX__)
/* only unix (or OS/2 with EMX!) can have terminfo instead of termcap */
# ifdef TERMINFO
	version_msg("+terminfo ");
# else
	version_msg("-terminfo ");
# endif
#else		    /* unix always includes termcap support */
# ifdef HAVE_TGETENT
	version_msg("+tgetent ");
# else
	version_msg("-tgetent ");
# endif
#endif
#ifdef VIMINFO
	version_msg("+viminfo ");
#else
	version_msg("-viminfo ");
#endif
#ifdef WRITEBACKUP
	version_msg("+writebackup ");
#else
	version_msg("-writebackup ");
#endif
#ifdef UNIX
# if defined(WANT_X11) && defined(HAVE_X11)
	version_msg("+X11 ");
# else
	version_msg("-X11 ");
# endif
#endif
	msg_putchar('\n');
#ifdef USR_VIMRC_FILE
	version_msg("   user vimrc file: \"");
	version_msg(USR_VIMRC_FILE);
	version_msg("\" ");
#endif
#ifdef USR_VIMRC_FILE2
	version_msg("2nd user vimrc file: \"");
	version_msg(USR_VIMRC_FILE2);
	version_msg("\" ");
#endif
#ifdef USR_EXRC_FILE
	version_msg("    user exrc file: \"");
	version_msg(USR_EXRC_FILE);
	version_msg("\" ");
#endif
#ifdef USR_EXRC_FILE2
	version_msg("2nd user exrc file: \"");
	version_msg(USR_EXRC_FILE2);
	version_msg("\" ");
#endif
#ifdef USE_GUI
	version_msg("  user gvimrc file: \"");
	version_msg(USR_GVIMRC_FILE);
	version_msg("\" ");
# ifdef USR_GVIMRC_FILE2
	version_msg("2nd user gvimrc file: \"");
	version_msg(USR_GVIMRC_FILE2);
	version_msg("\" ");
# endif
#endif
#ifdef SYS_VIMRC_FILE
	msg_putchar('\n');
	version_msg(" system vimrc file: \"");
	version_msg(SYS_VIMRC_FILE);
	version_msg("\"");
#endif
#ifdef USE_GUI
# ifdef SYS_GVIMRC_FILE
	msg_putchar('\n');
	version_msg("system gvimrc file: \"");
	version_msg(SYS_GVIMRC_FILE);
	MSG_PUTS("\"");
# endif
# ifdef SYS_MENU_FILE
	msg_putchar('\n');
	version_msg("  system menu file: \"");
	version_msg(SYS_MENU_FILE);
	MSG_PUTS("\"");
# endif
#endif
#ifdef HAVE_PATHDEF
	msg_putchar('\n');
	version_msg("  default for $VIM: \"");
	version_msg((char *)default_vim_dir);
	MSG_PUTS("\"\n");
	version_msg("Compilation: ");
	version_msg((char *)all_cflags);
	msg_putchar('\n');
	version_msg("Linking: ");
	version_msg((char *)all_lflags);
#endif
#ifdef DEBUG
	msg_putchar('\n');
	version_msg("  DEBUG BUILD");
#endif
    }
}

/*
 * Output a string for the version message.  If it's going to wrap, output a
 * newline, unless the message is too long to fit on the screen anyway.
 */
    static void
version_msg(s)
    char	*s;
{
    int		len = strlen(s);

    if (len < (int)Columns && msg_col + len >= (int)Columns)
	msg_putchar('\n');
    MSG_PUTS(s);
}
