" Vim syntax file
" Language:	Perl
" Maintainer:	Sonia Heimann <niania@netsurf.org>
" Last change:	1997 Nov 12

" Remove any old syntax stuff hanging around
syn clear

" A bunch of useful keywords. TODO : add all the "man perlfunc" functions!
syn keyword perlStatement	goto return last next
syn keyword perlLabel		case default
syn keyword perlConditional	if elsif unless else switch
syn keyword perlRepeat		while for foreach do
syn keyword perlOperator	defined undef
syn keyword perlMiscList	shift push pop split join keys each reverse
syn keyword perlMisc		print warn die exit open close rename

syn keyword perlTodo contained TODO TBD

" POD documentation starts with ^=head and ends with =cut
syntax region perlPOD start=+^=head+ end=+=cut+

" Perl Identifiers. 

" Plain identifier:
"   Scalar identifier: $foo
"   Array identifier: @foo
"   Array Length: $#foo
"   Hash identifier: %foo
"   Function identifier: &foo

" We do not process complex things such as @{${"foo"}}. Too complicated, and
" too slow. And what is after the -> is *not* considered as part of the
" variable - there again, too complicated and too slow.

" Special variables first ($^A, ...)
syn match  perlVarPlain "$^[A-Z]"
" Special variables, continued ($|, $', ...) 
syn match  perlVarPlain "$[\\\"\[\]'&`+*/|.,;=%~^:!@$<>()0-9-]"
" maybe add classical variables such as %ENV, @ARGS too ? 

" And plain identifiers
if exists("perl_want_scope_in_variables") 
" To highlight packages in variables as a scope ($pack::var : pack is a scope)
" declaration use :
  syn match perlPackageRef "[a-zA-Z_][a-zA-Z0-9_]*\>\('\|::\)"
  syn match perlVarPlain   "\(\$#\|\$\+\|@\|%\|\&\)[a-zA-Z_][a-zA-Z:'0-9_]*\>" contains=perlPackageRef
else
" Simple version
  syn match perlVarPlain   "\(\$#\|\$\+\|@\|%\|\&\)[a-zA-Z_][a-zA-Z:'0-9_]*\>"
endif

" String and Character constants

" Highlight special characters (those which have a backslash) differently
syn match   perlSpecial		contained "\\[0-9][0-9][0-9]\|\\."
" "" String may contain variables
syn region  perlString		start=+"+  skip=+\\\\\|\\"+  end=+"+ contains=perlSpecial,perlVarPlain
" '' Strings may not contain anything
syn region  perlStringUnexpanded start=+'+  skip=+\\\\\|\\"+  end=+'+ contains=perlSpecial
syn match   perlCharacter	 "'[^\\]'"
syn match   perlSpecialCharacter "'\\.'"

syn match  perlNumber		 "-\=\<[0-9]\+L\=\>\|0[xX][0-9a-fA-F]\+\>"

" Constructs such as print <<EOF [...] EOF
syn region perlUntilEOF start=+<<\(["`]\=\)EOF\1+hs=s+2 end=+^EOF$+
" When vim supports it, try to use something as
" syntax region perlUntilEOF start=+<<\(["`]\=\)\([a-zA-Z]\+\)\1+s+2 end=+^\2$+
" to allow any keyword, not just EOF. The \2 in the end pattern refers of
" course to the second group in the start pattern.


"syn sync ccomment perlComment

" Comments. 
" First, treat the the #!/bin/perl
syn match  perlSharpBang	"^#!.\+$"
" All other # are comment, when at the beginning of a line or after a space
" (avoid m## case ...)
syn match  perlComment		"^#\([^!].*\)\=$\|[ \t]#.*" contains=perlTodo

" Perl regexps, second version, thanks to Michael Firestone

" Any s### substitute (including the classical s///)
syn match perlSubstitute "[ \t]\=s\([^a-zA-Z0-9_ \t\n]\).\{-}[^\\]\(\\\\\)*\1.\{-}[^\\]\(\\\\\)*\1[xosmige]*" contains=perlVarPlain
" Any m## match
syn match perlMatchAny "m\([^a-zA-Z0-9_ \t\n]\).*[^\\]\(\\\\\)*\1[xosmige]*" contains=perlVarPlain
" The classical // construct
syn match perlMatch "/\(\\/\|[^/]\)*[^\\]\(\\\\\)*/[xosmige]*" contains=perlVarPlain
" Still TODO :  tr///, and y///
" q//, qq//, qx//, qw// are quite properly handled by perlMatch (maybe add a
" \(q[qxw]\=\)\= before to nicely highlight the keyword?)


syn keyword perlStorageClass		my local
syn match perlClassDecl		"^[ \t]*package\>[^;]*"

syn region  perlInclude		start=+^[ \t]*\<\(use\|require\)\>+ end=+;+he=e-1
syn keyword  perlControl	BEGIN END
syn match  perlLineSkip		"\\$"

" Functions ...
" find ^sub foo { . Only highlight foo.
" Function is sub foo { , sub foo( , sub foo;
syn region perlFunction start=+^[ \t]*sub[ \t]\++hs=e+1 end=+[;({]+me=s-1

if !exists("did_perl_syntax_inits")
  let did_perl_syntax_inits = 1
  " The default methods for highlighting.  Can be overridden later
  hi link perlSharpBang		PreProc
  hi link perlLabel		Label
  hi link perlConditional	Conditional
  hi link perlRepeat		Repeat
  hi link perlOperator		Operator
  hi link perlMiscList		perlStatement
  hi link perlMisc		perlStatement
  hi link perlVarPlain		perlIdentifier
  hi link perlVarObject		perlIdentifier
  hi link perlVarDerefPlain	perlIdentifier
  hi link perlVarDerefObject	perlIdentifier
  hi link perlStringUnexpanded	perlString
  hi link perlUntilEOF		perlString
  hi link perlCharacter		Character
  hi link perlSpecialCharacter	perlSpecial
  hi link perlMatchAny		perlMatch
  hi link perlSubstitute	perlMatch
  hi link perlNumber		Number
  hi link perlClassDecl		Typedef
  hi link perlStorageClass	perlType
  hi link perlPackageRef	perlType
  hi link perlInclude		Include
  hi link perlControl		PreProc

  hi link perlStatement		Statement
  hi link perlType		Type
  hi link perlString		String
  hi link perlPOD		perlComment
  hi link perlComment		Comment
  hi link perlSpecial		Special
  hi link perlTodo		Todo
  hi link perlFunction		Function
  hi link perlIdentifier	Identifier
endif

let b:current_syntax = "perl"

" vim: ts=8
