" Vim syntax support file
" Maintainer:	Bram Moolenaar <Bram@vim.org>
" Last change:	1997 Dec 22

" This is the startup file for syntax highlighting.
" 1. Set the default highlight groups.
" 2. Install autocommands for all the available syntax files.
" 3. Install the Syntax menu.

if has("syntax")

  " let others know that syntax has been switched on
  let syntax_on = 1

  " The default methods for highlighting.  Can be overridden later.
  " Many terminals can only use six different colors (plus black and white).
  " Therefore the number of colors used is kept low. It doesn't look nice with
  " too many colors anyway.
  " Careful with "cterm=bold", it may change the color to bright.

  " There are two sets of defaults: for a dark and a light background.
  if &background == "dark"
    hi Comment	term=bold ctermfg=Cyan guifg=#80a0ff
    hi Constant	term=underline ctermfg=Magenta guifg=#ffa0a0
    hi Special	term=bold ctermfg=LightRed guifg=Orange
    hi Identifier term=underline ctermfg=DarkCyan guifg=#40ffff
    hi Statement term=bold ctermfg=Yellow guifg=#ffff60 gui=bold
    hi PreProc	term=underline ctermfg=LightBlue guifg=#ff80ff
    hi Type	term=underline ctermfg=LightGreen guifg=#60ff60 gui=bold
  else
    hi Comment	term=bold ctermfg=Blue guifg=Blue
    hi Constant	term=underline ctermfg=Magenta guifg=Magenta
    hi Special	term=bold ctermfg=DarkBlue guifg=SlateBlue
    hi Identifier term=underline ctermfg=DarkCyan guifg=DarkCyan
    hi Statement term=bold ctermfg=Brown gui=bold guifg=Brown
    hi PreProc	term=underline ctermfg=Magenta guifg=Purple
    hi Type	term=underline ctermfg=DarkGreen guifg=SeaGreen gui=bold
  endif

  " These two change the background
  hi Error	term=reverse ctermbg=Red guibg=Orange
  hi Todo	term=standout ctermbg=Yellow guifg=Blue guibg=Yellow

  " Common groups that link to default highlighting.
  " You can specify other highlighting easily.
  hi link String	Constant
  hi link Character	Constant
  hi link Number	Constant
  hi link Boolean	Constant
  hi link Float		Number
  hi link Function	Identifier
  hi link Conditional	Statement
  hi link Repeat	Statement
  hi link Label		Statement
  hi link Operator	Statement
  hi link Keyword	Statement
  hi link Exception	Statement
  hi link Include	PreProc
  hi link Define	PreProc
  hi link Macro		PreProc
  hi link PreCondit	PreProc
  hi link StorageClass	Type
  hi link Structure	Type
  hi link Typedef	Type
  hi link Tag		Special
  hi link SpecialChar	Special
  hi link Delimiter	Special
  hi link SpecialComment Special
  hi link Debug		Special


  augroup syntax

  " First remove all old syntax autocommands.
  au!


  " Ada (83, 9X, 95)
  au BufNewFile,BufReadPost *.adb,*.ads		so $VIM/syntax/ada.vim

  " Assembly (GNU)
  au BufNewFile,BufReadPost *.asm,*.s		so $VIM/syntax/asm.vim

  " ASN.1
  au BufNewFile,BufReadPost *.asn,*.asn1	so $VIM/syntax/asn.vim

  " Awk
  au BufNewFile,BufReadPost *.awk		so $VIM/syntax/awk.vim

  " Batch file for MSDOS
  au BufNewFile,BufReadPost *.bat,*.sys		so $VIM/syntax/dosbatch.vim

  " BibTeX bibliography database file
  au BufNewFile,BufReadPost *.bib		so $VIM/syntax/bib.vim

  " C
  au BufNewFile,BufReadPost *.c			so $VIM/syntax/c.vim

  " C++
  if has("fname_case")
    au BufNewFile,BufReadPost *.cpp,*.cc,*.h,*.cxx,*.c++,*.C,*.H,*.hh,*.inl so $VIM/syntax/cpp.vim
  else
    au BufNewFile,BufReadPost *.cpp,*.cc,*.h,*.cxx,*.c++,*.hh,*.inl so $VIM/syntax/cpp.vim
  endif

  " Century Term Command Scripts
  au BufNewFile,BufReadPost *.cmd,*.con		so $VIM/syntax/cterm.vim

  " Diff files
  au BufNewFile,BufReadPost *.diff,*.rej	so $VIM/syntax/diff.vim

  " Dracula
  au BufNewFile,BufReadPost drac.*,*.drac,*.drc,*lvs,*lpe so $VIM/syntax/dracula.vim

  " ESQL-C
  au BufNewFile,BufReadPost *.ec,*.EC		so $VIM/syntax/esqlc.vim

  " Fortran
  au BufNewFile,BufReadPost *.f,*.F,*.for,*.fpp	so $VIM/syntax/fortran.vim

  " HTML
  au BufNewFile,BufReadPost *.html,*.htm	so $VIM/syntax/html.vim

  " IDL (Interface Description Language)
  au BufNewFile,BufReadPost *.idl		so $VIM/syntax/idl.vim

  " Inform
  au BufNewFile,BufReadPost *.inf,*.INF		so $VIM/syntax/inform.vim

  " .INI file for MSDOS
  au BufNewFile,BufReadPost *.ini		so $VIM/syntax/dosini.vim

  " Java
  au BufNewFile,BufReadPost *.java,*.jav	so $VIM/syntax/java.vim

  " JavaCC
  au BufNewFile,BufReadPost *.jj		so $VIM/syntax/javacc.vim

  " JavaScript
  au BufNewFile,BufReadPost *.js,*.javascript	so $VIM/syntax/javascript.vim

  " Lex
  au BufNewFile,BufReadPost *.lex,*.l		so $VIM/syntax/lex.vim

  " Lisp
  au BufNewFile,BufReadPost *.lsp,*.L		so $VIM/syntax/lisp.vim

  " Lynx style file
  au BufNewFile,BufReadPost *.lss		so $VIM/syntax/lss.vim

  " Mail (for Elm, trn and rn)
  au BufNewFile,BufReadPost snd.*,.letter,.article,.article.[0-9]\+,pico.[0-9]\+,mutt*[0-9] so $VIM/syntax/mail.vim

  " Makefile
  au BufNewFile,BufReadPost [mM]akefile*,*.mk,*.mak so $VIM/syntax/make.vim

  " Maple V
  au BufNewFile,BufReadPost *.mv		so $VIM/syntax/maple.vim

  " Matlab
  au BufNewFile,BufReadPost *.m			so $VIM/syntax/matlab.vim

  " Modula 2
  au BufNewFile,BufReadPost *.m2		so $VIM/syntax/modula2.vim

  " Pascal
  au BufNewFile,BufReadPost *.p,*.pas		so $VIM/syntax/pascal.vim

  " Perl
  au BufNewFile,BufReadPost *.pl,*.pm		so $VIM/syntax/perl.vim

  " Perl POD
  au BufNewFile,BufReadPost *.pod		so $VIM/syntax/pod.vim

  " PostScript
  au BufNewFile,BufReadPost *.ps,*.eps		so $VIM/syntax/postscr.vim

  " Procmail
  au BufNewFile,BufReadPost .procmail		so $VIM/syntax/procmail.vim

  " Prolog
  au BufNewFile,BufReadPost *.pdb		so $VIM/syntax/prolog.vim

  " Python
  au BufNewFile,BufReadPost *.py		so $VIM/syntax/python.vim

  " Sather
  au BufNewFile,BufReadPost *.sa		so $VIM/syntax/sather.vim

  " Sendmail
  au BufNewFile,BufReadPost sendmail.cf		so $VIM/syntax/sm.vim

  " Shell scripts (sh, ksh, bash, csh)
  au BufNewFile,BufReadPost .profile,.bashrc,*.sh,*.ksh,*.bash,*.env so $VIM/syntax/sh.vim
  au BufNewFile,BufReadPost .login,.cshrc,*.csh,*.tcsh so $VIM/syntax/csh.vim

  " Z-Shell script
  au BufNewFile,BufReadPost .z*,zsh*,zlog*	so $VIM/syntax/zsh.vim

  " SQL
  au BufNewFile,BufReadPost *.sql		so $VIM/syntax/sql.vim

  " Telix Salt
  au BufNewFile,BufReadPost *.slt		so $VIM/syntax/tsalt.vim

  " TeX
  au BufNewFile,BufReadPost *.tex,*.sty		so $VIM/syntax/tex.vim

  " Motif UIT/UIL files
  au BufNewFile,BufReadPost *.uit,*.uil         so $VIM/syntax/uil.vim

  " Verilog HDL
  au BufNewFile,BufReadPost *.v			so $VIM/syntax/verilog.vim

  " Tcl
  au BufNewFile,BufReadPost *.tcl		so $VIM/syntax/tcl.vim

  " VHDL
  au BufNewFile,BufReadPost *.hdl,*.vhd,*.vhdl,*.vhdl_[0-9]*,*.vbe,*.vst  so $VIM/syntax/vhdl.vim

  " Vim Help file
  au BufNewFile,BufReadPost */vim*/doc/*.txt	so $VIM/syntax/help.vim

  " Vim script
  au BufNewFile,BufReadPost *.*vimrc,vimrc,gvimrc,*.vim,.exrc,_*vimrc,_exrc so $VIM/syntax/vim.vim

  " Viminfo file
  au BufNewFile,BufReadPost .viminfo,_viminfo	so $VIM/syntax/viminfo.vim

  " Vgrindefs file
  au BufNewFile,BufReadPost vgrindefs		so $VIM/syntax/vgrindefs.vim

  " VRML V1.0c
  au BufNewFile,BufReadPost *.wrl		so $VIM/syntax/vrml.vim

  " Xmath
  au BufNewFile,BufReadPost *.ms,*.msc,*.msf	so $VIM/syntax/xmath.vim

  " Yacc
  au BufNewFile,BufReadPost *.y			so $VIM/syntax/yacc.vim

  " Various scripts, without a specific extension
  au BufNewFile,BufReadPost *			so $VIM/syntax/scripts.vim

  augroup END

  if has("gui")
    50amenu Syntax.off			:syn clear
    50amenu Syntax.ABCDE.Ada		:so $VIM/syntax/ada.vim
    50amenu Syntax.ABCDE.Amiga\ DOS	:so $VIM/syntax/amiga.vim
    50amenu Syntax.ABCDE.assembly	:so $VIM/syntax/asm.vim
    50amenu Syntax.ABCDE.ASN\.1		:so $VIM/syntax/asn.vim
    50amenu Syntax.ABCDE.Awk		:so $VIM/syntax/awk.vim
    50amenu Syntax.ABCDE.BibFile	:so $VIM/syntax/bib.vim
    50amenu Syntax.ABCDE.C		:so $VIM/syntax/c.vim
    50amenu Syntax.ABCDE.C++		:so $VIM/syntax/cpp.vim
    50amenu Syntax.ABCDE.Century\ Term	:so $VIM/syntax/cterm.vim
    50amenu Syntax.ABCDE.Csh\ shell\ script :so $VIM/syntax/csh.vim
    50amenu Syntax.ABCDE.Diff		:so $VIM/syntax/diff.vim
    50amenu Syntax.ABCDE.Dracula	:so $VIM/syntax/dracula.vim
    50amenu Syntax.ABCDE.ESQL-C		:so $VIM/syntax/esqlc.vim
    50amenu Syntax.ABCDE.Expect		:so $VIM/syntax/expect.vim
    50amenu Syntax.FGHIJ.Fortran	:so $VIM/syntax/fortran.vim
    50amenu Syntax.FGHIJ.HTML		:so $VIM/syntax/html.vim
    50amenu Syntax.FGHIJ.IDL		:so $VIM/syntax/idl.vim
    50amenu Syntax.FGHIJ.Inform		:so $VIM/syntax/inform.vim
    50amenu Syntax.FGHIJ.Java		:so $VIM/syntax/java.vim
    50amenu Syntax.FGHIJ.JavaCC		:so $VIM/syntax/javacc.vim
    50amenu Syntax.FGHIJ.JavaScript	:so $VIM/syntax/javascript.vim
    50amenu Syntax.KLMNO.Lex		:so $VIM/syntax/lex.vim
    50amenu Syntax.KLMNO.Lisp		:so $VIM/syntax/lisp.vim
    50amenu Syntax.KLMNO.Lynx\ Style	:so $VIM/syntax/lss.vim
    50amenu Syntax.KLMNO.Mail		:so $VIM/syntax/mail.vim
    50amenu Syntax.KLMNO.Makefile	:so $VIM/syntax/make.vim
    50amenu Syntax.KLMNO.Maple		:so $VIM/syntax/maple.vim
    50amenu Syntax.KLMNO.Matlab		:so $VIM/syntax/matlab.vim
    50amenu Syntax.KLMNO.Model		:so $VIM/syntax/model.vim
    50amenu Syntax.KLMNO.Modula\ 2	:so $VIM/syntax/modula2.vim
    50amenu Syntax.KLMNO.MS-DOS\ \.bat\ file :so $VIM/syntax/dosbatch.vim
    50amenu Syntax.KLMNO.MS-DOS\ \.ini\ file :so $VIM/syntax/dosini.vim
    50amenu Syntax.KLMNO.Objective\ C	:so $VIM/syntax/objc.vim
    50amenu Syntax.PQRST.Pascal		:so $VIM/syntax/pascal.vim
    50amenu Syntax.PQRST.Perl		:so $VIM/syntax/perl.vim
    50amenu Syntax.PQRST.Perl\ POD	:so $VIM/syntax/pod.vim
    50amenu Syntax.PQRST.PostScript	:so $VIM/syntax/postscr.vim
    50amenu Syntax.PQRST.Procmail	:so $VIM/syntax/procmail.vim
    50amenu Syntax.PQRST.Prolog		:so $VIM/syntax/prolog.vim
    50amenu Syntax.PQRST.Python		:so $VIM/syntax/python.vim
    50amenu Syntax.PQRST.Sather		:so $VIM/syntax/sather.vim
    50amenu Syntax.PQRST.Sendmail\.cf	:so $VIM/syntax/sm.vim
    50amenu Syntax.PQRST.Sh\ shell\ script :so $VIM/syntax/sh.vim
    50amenu Syntax.PQRST.SQL		:so $VIM/syntax/sql.vim
    50amenu Syntax.PQRST.Telix\ Salt	:so $VIM/syntax/tsalt.vim
    50amenu Syntax.PQRST.Tex		:so $VIM/syntax/tex.vim
    50amenu Syntax.PQRST.Tcl		:so $VIM/syntax/tcl.vim
    50amenu Syntax.UVWXYZ.UIT/UIL	:so $VIM/syntax/uil.vim
    50amenu Syntax.UVWXYZ.Verilog\ HDL	:so $VIM/syntax/verilog.vim
    50amenu Syntax.UVWXYZ.VHDL		:so $VIM/syntax/vhdl.vim
    50amenu Syntax.UVWXYZ.Vim\ help\ file :so $VIM/syntax/help.vim
    50amenu Syntax.UVWXYZ.Vim\ script	:so $VIM/syntax/vim.vim
    50amenu Syntax.UVWXYZ.Viminfo\ file	:so $VIM/syntax/viminfo.vim
    50amenu Syntax.UVWXYZ.vgrindefs	:so $VIM/syntax/vgrindefs.vim
    50amenu Syntax.UVWXYZ.VRML		:so $VIM/syntax/vrml.vim
    50amenu Syntax.UVWXYZ.Xmath		:so $VIM/syntax/xmath.vim
    50amenu Syntax.UVWXYZ.Yacc		:so $VIM/syntax/yacc.vim
    50amenu Syntax.UVWXYZ.Zsh\ shell\ script :so $VIM/syntax/zsh.vim
    50amenu Syntax.Color\ test		:sp $VIM/syntax/colortest.vim|so %
    50amenu Syntax.manual		:normal :augroup syntax
:au!
:augroup END
:syn clear
:aunmenu Syntax.manual
:50amenu Syntax.automatic :aunmenu Syntax.automatic|so $VIM/syntax/syntax.vim



  endif


" Source the user-specified syntax highlighting file
  if exists("mysyntaxfile")
    execute "source " . mysyntaxfile
  endif


  " Execute the syntax autocommands for the each buffer.
  doautoall syntax BufReadPost

endif

" vim: ts=8
